summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyaccounttreebudget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneyaccounttreebudget.h')
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreebudget.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/widgets/kmymoneyaccounttreebudget.h b/kmymoney2/widgets/kmymoneyaccounttreebudget.h
index 1b5139a..6f3c244 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreebudget.h
+++ b/kmymoney2/widgets/kmymoneyaccounttreebudget.h
@@ -60,7 +60,7 @@ public:
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param budget const reference to the budget to
* which the account belongs
* @param price price to be used to calculate value (defaults to 1)
@@ -77,7 +77,7 @@ public:
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param budget const reference to the budget to
* which the account belongs
* @param security const reference to the security used to show the value. Usually
@@ -85,7 +85,7 @@ public:
* @param name name of the account to be used instead of the one stored with @p account
* If empty, the one stored with @p account will be used. Default: empty
*/
- KMyMoneyAccountTreeBudgetItem(KListView *parent, const MyMoneyAccount& account, const MyMoneyBudget &budget, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
+ KMyMoneyAccountTreeBudgetItem(TDEListView *parent, const MyMoneyAccount& account, const MyMoneyBudget &budget, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
~KMyMoneyAccountTreeBudgetItem();
@@ -60,7 +60,7 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param budget const reference to the budget to
* which the account belongs
@@ -77,7 +77,7 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param budget const reference to the budget to
* which the account belongs